==> GOSemSim_1.28.2.tar.gz: GOSemSim/README.md <==
#  GOSemSim

[![platform](http://www.bioconductor.org/shields/availability/devel/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#archives)
[![Build Status](http://www.bioconductor.org/shields/build/devel/bioc/GOSemSim.svg)](http://bioconductor.org/checkResults/devel/bioc-LATEST/GOSemSim/)
[![Bioc](http://www.bioconductor.org/shields/years-in-bioc/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#since)
[![post](http://www.bioconductor.org/shields/posts/GOSemSim.svg)](https://support.bioconductor.org/t/GOSemSim/)
[![commit](http://www.bioconductor.org/shields/commits/bioc/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#svn_source)
[![download](http://www.bioconductor.org/shields/downloads/GOSemSim.svg)](http://bioconductor.org/packages/stats/bioc/GOSemSim.html)

Implemented five methods proposed by Resnik, Schlicker, Jiang, Lin and Wang respectively for estimating GO semantic similarities. Support many species, including Anopheles, Arabidopsis, Bovine, Canine, Chicken, Chimp, Coelicolor, E coli strain K12 and Sakai, Fly, Human, Malaria, Mouse, Pig, Rhesus, Rat, Worm, Xenopus, Yeast, and Zebrafish.

## Authors ##

Guangchuang YU, School of Public Health, The University of Hong Kong [http://ygc.name](http://ygc.name)

## Citation ##

Please cite the following article when using `GOSemSim`:

```
Yu G, Li F, Qin Y, Bo X, Wu Y and Wang S. 
GOSemSim: an R package for measuring semantic similarity among GO terms and gene products.
Bioinformatics, 2010, 26(7):976-978. 
```

URL: [http://bioinformatics.oxfordjournals.org/content/26/7/976.full](http://bioinformatics.oxfordjournals.org/content/26/7/976.full)

## License ##

All source code is copyright, under the Artistic-2.0 License.
For more information on Artistic-2.0 License see [http://opensource.org/licenses/Artistic-2.0](http://opensource.org/licenses/Artistic-2.0)

## Installation ##

To install:
 * the latest released version:
   `biocLite("GOSemSim")`
 * the latest development version:
   `install_github("GuangchuangYu/GOSemSim")`

Find out more at [http://www.bioconductor.org/packages/release/bioc/html/GOSemSim.html](http://www.bioconductor.org/packages/release/bioc/html/GOSemSim.html) and check out the [vignette](http://www.bioconductor.org/packages/release/bioc/vignettes/clusterProfiler/inst/doc/GOSemSim.pdf).


## External documents

+ [proper use of GOSemSim](http://ygc.name/2014/11/23/proper-use-of-gosemsim/)
+ [using GOSemSim to rank proteins obtained by co-IP](http://ygc.name/2015/05/04/using-gosemsim-to-rank-proteins-obtained-by-co-ip/)
+ [Proper use of GOSemSim](https://github.com/GuangchuangYu/GOSemSim/wiki/Proper-use-of-GOSemSim)

## Bugs/Feature requests ##

 - If you have any, [let me know](https://github.com/GuangchuangYu/GOSemSim/issues). Thx!

==> GOSemSim_1.30.3.tar.gz: GOSemSim/README.md <==
#  GOSemSim

[![platform](http://www.bioconductor.org/shields/availability/devel/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#archives)
[![Build Status](http://www.bioconductor.org/shields/build/devel/bioc/GOSemSim.svg)](http://bioconductor.org/checkResults/devel/bioc-LATEST/GOSemSim/)
[![Bioc](http://www.bioconductor.org/shields/years-in-bioc/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#since)
[![post](http://www.bioconductor.org/shields/posts/GOSemSim.svg)](https://support.bioconductor.org/t/GOSemSim/)
[![commit](http://www.bioconductor.org/shields/commits/bioc/GOSemSim.svg)](http://www.bioconductor.org/packages/devel/bioc/html/GOSemSim.html#svn_source)
[![download](http://www.bioconductor.org/shields/downloads/GOSemSim.svg)](http://bioconductor.org/packages/stats/bioc/GOSemSim.html)
[![gitter](https://img.shields.io/badge/GITTER-join%20chat-green.svg)](https://gitter.im/GuangchuangYu/Bioinformatics)

Implemented five methods proposed by Resnik, Schlicker, Jiang, Lin and Wang respectively for estimating GO semantic similarities. Support many species, including Anopheles, Arabidopsis, Bovine, Canine, Chicken, Chimp, Coelicolor, E coli strain K12 and Sakai, Fly, Human, Malaria, Mouse, Pig, Rhesus, Rat, Worm, Xenopus, Yeast, and Zebrafish.

## Authors ##

Guangchuang YU, School of Public Health, The University of Hong Kong <http://guangchuangyu.github.io>

## Citation ##

Please cite the following article when using `GOSemSim`:

```
Yu G, Li F, Qin Y, Bo X, Wu Y and Wang S. 
GOSemSim: an R package for measuring semantic similarity among GO terms and gene products.
Bioinformatics, 2010, 26(7):976-978. 
```

URL: [http://bioinformatics.oxfordjournals.org/content/26/7/976.full](http://bioinformatics.oxfordjournals.org/content/26/7/976.full)

## License ##

All source code is copyright, under the Artistic-2.0 License.
For more information on Artistic-2.0 License see [http://opensource.org/licenses/Artistic-2.0](http://opensource.org/licenses/Artistic-2.0)

## Installation ##

To install:
 * the latest released version:
   `biocLite("GOSemSim")`
 * the latest development version:
   `devtools::install_github("GuangchuangYu/GOSemSim")`

Find out more at [http://www.bioconductor.org/packages/release/bioc/html/GOSemSim.html](http://www.bioconductor.org/packages/release/bioc/html/GOSemSim.html) and check out the [vignette](http://www.bioconductor.org/packages/release/bioc/vignettes/clusterProfiler/inst/doc/GOSemSim.pdf).


## Documentation ##


To view the vignette of `GOSemSim` installed in your system, start R and enter:
```r
vignette("GOSemSim", package="GOSemSim")
```

More documents can be found in <http://www.bioconductor.org/packages/clusterProfiler>, <http://www.bioconductor.org/packages/DOSE> and <http://guangchuangyu.github.io/tags/gosemsim>.

## Bugs/Feature requests ##

 - If you have any, [let me know](https://github.com/GuangchuangYu/GOSemSim/issues). Thx!
